@@ -10,6 +10,7 @@ from gantry.logger.main import (
     log_record,
     log_records,
     ping,
+    ready,
     setup_logger,
 )
 from gantry.utils import compute_feedback_id
@@ -21,6 +22,7 @@ __all__ = [
     "log_records",
     "log_file",
     "ping",
+    "ready",
     "log_feedback",
     "log_predictions",
     "log_feedback_event",
