@@ -251,7 +251,7 @@ class Gantry:
         inputs: Optional[Union[List[dict], pd.DataFrame]] = None,
         outputs: Optional[Union[List[Any], List[dict], pd.DataFrame]] = None,
         feedback_keys: Optional[List[str]] = None,
-        feedback_ids: Optional[List[dict]] = None,
+        feedback_ids: Optional[Union[List[str], List[dict]]] = None,
         feedbacks: Optional[Union[List[dict], pd.DataFrame]] = None,
         ignore_inputs: Optional[List[str]] = None,
         timestamps: Optional[Union[List[datetime.datetime], pd.DatetimeIndex]] = None,
@@ -294,6 +294,8 @@ class Gantry:
                 validation by Gantry.
                 If not provided, Gantry will use the latest version. If the version doesn't exist
                 yet, Gantry will create it by auto-generating the schema based on data it has seen.
+                Providing an int or its value stringified has no difference
+                (e.g. version=10 will be the same as version='10').
             inputs (Union[List[dict], pd.Dataframe]): A list of prediction inputs. `inputs[i]`
                 is a dict of the features for the i-th prediction to be logged.
             outputs (Union[List[dict], pd.Dataframe]): A list of prediction outputs. `outputs[i]`
@@ -302,9 +304,13 @@ class Gantry:
                 feedback lookup. When you later provide a feedback event or label for
                 performance metric calculation, you will provide the values of the features
                 in this list for Gantry to look up the corresponding prediction.
-            feedback_ids (optional, List[dict]): A list of prediction feedback ids. The i-th entry
-                corresponds to the argument `feedback_ids` in
+            feedback_ids (optional, List[str] or List[dict]): A list of prediction feedback ids.
+                The i-th entry corresponds to the argument `feedback_ids` in
                 :meth:`gantry.client.Gantry.log_predictions` for the i-th prediction event.
+                If the feedback_id is a List[str], then the exact value of the i-th element in the
+                list is used as the feedback join id for the i-th event.
+                If the feedback_id is a Dict[str], then the values of the dictionary will be hashed
+                to create a feedback join id for the i-th event.
             feedbacks (Union[List[dict], pd.DataFrame]): A list of feedbacks. `feedbacks[i]`
                 is a dict of the features for the i-th prediction to be logged.
             ignore_inputs (optional, List[str]): A list of names of input features that should not
@@ -482,7 +488,7 @@ class Gantry:
         version: Optional[Union[int, str]] = None,
         inputs: Optional[dict] = None,
         outputs: Optional[Any] = None,
-        feedback_id: Optional[dict] = None,
+        feedback_id: Optional[Union[str, dict]] = None,
         feedback: Optional[dict] = None,
         feedback_keys: Optional[List[str]] = None,
         ignore_inputs: Optional[List[str]] = None,
@@ -519,9 +525,12 @@ class Gantry:
         Args:
             application (str): Name of the application. Gantry validates and monitors data by
                 function.
-            version (optional, int): Version of the function schema to use for validation by Gantry.
+            version (optional, Union[int, str]): Version of the function schema to use
+                for validation by Gantry.
                 If not provided, Gantry will use the latest version. If the version doesn't exist
                 yet, Gantry will create it by auto-generating the schema based on data it has seen.
+                Providing an int or its value stringified has no difference
+                (e.g. version=10 will be the same as version='10').
             inputs (optional, dict): Inputs to the prediction. A dict where the keys are the feature
                 names and the values are the feature values.
             outputs (optional, Any): application output on the prediction.
@@ -641,7 +650,7 @@ class Gantry:
         fev = _build_feedback_event(
             context,
             application,
-            feedback_id,  # type: ignore
+            feedback_id,
             feedback,  # type: ignore
             version,
             timestamp,
@@ -656,7 +665,7 @@ class Gantry:
     def log_feedback_event(
         self,
         application: str,
-        feedback_id: dict,
+        feedback_id: Union[str, dict],
         feedback: dict,
         feedback_version: Optional[Union[str, int]] = None,
         timestamp: Optional[datetime.datetime] = None,
@@ -713,7 +722,7 @@ class Gantry:
     def log_feedback(
         self,
         application: str,
-        feedback_ids: List[dict],
+        feedback_ids: Union[List[str], List[dict]],
         feedbacks: Union[List[dict], pd.DataFrame],
         feedback_version: Optional[Union[str, int]] = None,
         timestamps: Optional[Union[List[datetime.datetime], pd.DatetimeIndex]] = None,
@@ -731,12 +740,13 @@ class Gantry:
         invalid parameters.
 
         Args:
-            feedback_ids (list): A list of dicts. dict where the keys are feedback keys
-                (as specified in the `feedback_keys` arg of `gantry.instrument` or
-                `log_prediction_event(s)`) and the value matches the value in the
-                corresponding prediction. The feedback event is matched to the prediction
-                event using the values of the feedback keys. The i-th feedback_id maps to
-                the i-th feedback.
+            feedback_ids (List[str] or List[dict]): A list of prediction feedback ids.
+                The i-th entry corresponds to the argument `feedback_ids` in
+                :meth:`gantry.client.Gantry.log_predictions` for the i-th prediction event.
+                If the feedback_id is a List[str], then the exact value of the i-th element in the
+                list is used as the feedback join id for the i-th event.
+                If the feedback_id is a Dict[str], then the values of the dictionary will be hashed
+                to create a feedback join id for the i-th event.
             feedback (list): List of application feedback objects.
             feedback_version (optional, int or str): Specify application version.
             timestamps (optional, datetime.datetime): Record timestamps. The i-th timestamp
@@ -819,7 +829,7 @@ class Gantry:
         version: Optional[Union[int, str]] = None,
         feedback_keys: Optional[List[str]] = None,
         ignore_inputs: Optional[List[str]] = None,
-        feedback_id: Optional[dict] = None,
+        feedback_id: Optional[Union[str, dict]] = None,
         timestamp: Optional[datetime.datetime] = None,
         sample_rate: float = 1.0,
         tags: Optional[Dict[str, str]] = None,
@@ -908,7 +918,7 @@ class Gantry:
         version: Optional[Union[int, str]] = None,
         feedback_keys: Optional[List[str]] = None,
         ignore_inputs: Optional[List[str]] = None,
-        feedback_ids: Optional[List[dict]] = None,
+        feedback_ids: Optional[Union[List[str], List[dict]]] = None,
         timestamps: Optional[Union[List[datetime.datetime], pd.DatetimeIndex]] = None,
         sort_on_timestamp: bool = True,
         sample_rate: float = 1.0,
@@ -931,8 +941,8 @@ class Gantry:
                 If specified, `timestamps[i]` should be the timestamp for the i-th prediction.
                 If timestamps = None (default), then the prediction timestamp defaults to the
                 time when `log_predictions` is called.
-            feedback_ids (optional, List[dict]): A list of prediction feedback ids. The i-th entry
-                corresponds to the argument `feedback_id` in
+            feedback_ids (optional, List[str] or List[dict]): A list of prediction feedback ids.
+                The i-th entry corresponds to the argument `feedback_id` in
                 :meth:`gantry.client.Gantry.log_prediction_event` for the i-th prediction event.
             **kwargs: The rest of the arguments are the same as in
                 :meth:`gantry.client.Gantry.instrument`.
