@@ -1,15 +1,15 @@
 from enum import Enum
 
 
-class BatchTypes(Enum):
+class BatchType(str, Enum):
     RECORD = "RECORD"
     FEEDBACK = "FEEDBACK"
     PREDICTION = "PREDICTION"
-    FILE = "FILE"
 
 
 class UploadFileType(str, Enum):
     CSV_WITH_HEADERS = "CSV_WITH_HEADERS"
+    EVENTS_BYTES = "EVENTS_BYTES"
 
 
 class Delimiter(Enum):
