@@ -107,7 +107,7 @@ def _enrich_events_with_batch_id(events, batch_id):
 def _build_feedback_event(
     context: dict,
     application: str,
-    feedback_id: dict,
+    feedback_id: Union[str, dict],
     feedback: dict,
     feedback_version: Optional[Union[str, int]] = None,
     timestamp: Optional[datetime.datetime] = None,
@@ -119,7 +119,10 @@ def _build_feedback_event(
     metadata: Dict[str, Any] = {}
     metadata.update(context)
     metadata.update({"func_name": application, "feedback_version": feedback_version})
-    computed_feedback_id = compute_feedback_id(feedback_id, list(feedback_id.keys()))
+    if isinstance(feedback_id, str):
+        computed_feedback_id = feedback_id
+    else:
+        computed_feedback_id = compute_feedback_id(feedback_id, list(feedback_id.keys()))
 
     log_time = datetime.datetime.utcnow()
     event_time = timestamp if timestamp else log_time
@@ -157,7 +160,7 @@ def _build_prediction_events(
     version: Optional[Union[str, int]],
     feedback_keys: Optional[List[str]] = None,
     ignore_inputs: Optional[List[str]] = None,
-    feedback_ids: Optional[List[dict]] = None,
+    feedback_ids: Optional[Union[List[str], List[dict]]] = None,
     sample_rate: float = 1.0,
     batch_id: Optional[str] = None,
     tags: Optional[Dict[str, str]] = None,
@@ -201,7 +204,7 @@ def _build_prediction_event(
     feedback_keys: Optional[List[str]],
     ignore_inputs: Optional[List[str]],
     batch_id: Optional[str] = None,
-    feedback_id: Optional[dict] = None,
+    feedback_id: Optional[Union[str, dict]] = None,
     tags: Optional[Dict[str, str]] = None,
     custom_timestamp: Optional[datetime.datetime] = None,
 ):
@@ -223,8 +226,13 @@ def _build_prediction_event(
             raise GantryLoggingException(
                 "Cannot specify feedback_id and feedback_keys at same time."
             )
-        # Compute feedback_id just from provided feedback_id dictionary
-        computed_feedback_id = compute_feedback_id(feedback_id, list(feedback_id.keys()))
+
+        if isinstance(feedback_id, str):
+            # Set the feedback_id directly from the given string.
+            computed_feedback_id = feedback_id
+        else:
+            # Compute feedback_id just from provided feedback_id dictionary
+            computed_feedback_id = compute_feedback_id(feedback_id, list(feedback_id.keys()))
     else:
         computed_feedback_id = compute_feedback_id(inputs, feedback_keys)
 
