@@ -186,7 +186,8 @@ class GantryDataFrame(GantryQueryFrame):
         return pd.Series(self._dtypes).sort_index(ascending=True)
 
     def head(self, n: int = 5) -> pd.DataFrame:  # type: ignore
-        """Fetch the top n entries
+        """Fetch the top n entries. Results will include an additional column, `join_id`,
+        whose values can be used to log and join feedback events to your Gantry application.
 
         Args:
             n (int, defaults to 5): Number of entries to fetch
@@ -197,7 +198,8 @@ class GantryDataFrame(GantryQueryFrame):
         return self._head(n=n, query_filters=self.filters, tags=self.tags)
 
     def tail(self, n: int = 5) -> pd.DataFrame:  # type: ignore
-        """Fetch the last n entries
+        """Fetch the last n entries. Results will include an additional column, `join_id`,
+        whose values can be used to log and join feedback events to your Gantry application.
 
         Args:
             n (int, defaults to 5): Number of entries to fetch
@@ -208,7 +210,8 @@ class GantryDataFrame(GantryQueryFrame):
         return self._tail(n=n, query_filters=self.filters, tags=self.tags)
 
     def fetch(self) -> pd.DataFrame:  # type: ignore
-        """Fetch all entries
+        """Fetch all entries. Results will include an additional column, `join_id`,
+        whose values can be used to log and join feedback events to your Gantry application.
 
         Returns:
             A pandas dataframe object.
