@@ -192,7 +192,10 @@ class GantryQueryFrame(object):
         if not (n > 0):
             raise ValueError("n must be a positive int. Got {}".format(n))
         data = self._populate_raw_request(
-            query_filters=query_filters, ascending=True, n=n, tags=tags
+            query_filters=query_filters,
+            ascending=True,
+            n=n,
+            tags=tags,
         )
         return self._prepare_pandas_dataframe(data, column)
 
@@ -215,7 +218,10 @@ class GantryQueryFrame(object):
         if not (n > 0):
             raise ValueError("n must be a positive int. Got {}".format(n))
         data = self._populate_raw_request(
-            query_filters=query_filters, ascending=False, n=n, tags=tags
+            query_filters=query_filters,
+            ascending=False,
+            n=n,
+            tags=tags,
         )
         return self._prepare_pandas_dataframe(data, column)
 
@@ -229,7 +235,10 @@ class GantryQueryFrame(object):
         Return all data in the query window.
         """
         data = self._populate_raw_request(
-            query_filters=query_filters, ascending=True, n=None, tags=tags
+            query_filters=query_filters,
+            ascending=True,
+            n=None,
+            tags=tags,
         )
         return self._prepare_pandas_dataframe(data, column)
 
@@ -255,6 +264,7 @@ class GantryQueryFrame(object):
             json_data["limit"] = n
 
         json_data["order"] = ORDER_ASCENDING if ascending else ORDER_DESCENDING
+        json_data["include_join_id"] = True
 
         events = []
         has_next = True
