@@ -82,6 +82,7 @@ def test_populate_raw_request_descending_no_pagination(n, tags, env, expected, a
         matcher["limit"] = n
 
     matcher["order"] = "descending"
+    matcher["include_join_id"] = True
     expected_events = list("these-are-events")[:n] if n else list("these-are-events")
     with responses.RequestsMock() as rsps:
         rsps.add(
@@ -129,6 +130,7 @@ def test_populate_raw_request_ascending_no_pagination(n, tags, env, expected, ap
         matcher["limit"] = n
 
     matcher["order"] = "ascending"
+    matcher["include_join_id"] = True
 
     expected_events = list("these-are-events")[:n] if n else list("these-are-events")
     with responses.RequestsMock() as rsps:
@@ -180,6 +182,7 @@ def test_populate_raw_request_ascending_pagination(n, tags, env, expected, api_c
     first_matcher = {"tags": expected} if expected else {}
     first_matcher["limit"] = n
     first_matcher["order"] = "ascending"
+    first_matcher["include_join_id"] = True
 
     second_matcher = first_matcher.copy()
     second_matcher["offset"] = len(requested_events[:up_to])
@@ -252,6 +255,7 @@ def test_populate_raw_request_descending_pagination(n, tags, env, expected, api_
     first_matcher = {"tags": expected} if expected else {}
     first_matcher["limit"] = n
     first_matcher["order"] = "descending"
+    first_matcher["include_join_id"] = True
 
     second_matcher = first_matcher.copy()
     second_matcher["offset"] = len(requested_events[:up_to])
