@@ -212,9 +212,10 @@ def test_dtype(series_obj):
     assert series_obj._dtype() == "int"
 
 
+@pytest.mark.parametrize("tags", [{}, {"foo": "bar"}])
 @pytest.mark.parametrize("filters", [[], [{"some": "filter"}]])
 @mock.patch("gantry.query.core.dataframe._raw_query_cached_request")
-def test_aggregate_query(mock_query_data, series_obj_factory_with_filters, filters):
+def test_aggregate_query(mock_query_data, series_obj_factory_with_filters_and_tags, filters, tags):
     content = json.dumps(
         {
             "start_time": "2008-09-03T20:56:35",
@@ -228,22 +229,26 @@ def test_aggregate_query(mock_query_data, series_obj_factory_with_filters, filte
                     "stat_kwargs": {"some-attribute": {"a": 10}},
                     "feature": "series_name",
                     "filters": filters,
+                    "tags": tags,
                 }
             },
         },
         default=lambda x: x.isoformat(),
     )
-    series_obj = series_obj_factory_with_filters("int", filters=filters)
+    series_obj = series_obj_factory_with_filters_and_tags("int", filters=filters, tags=tags)
     mock_query_data.return_value = {"response": "ok", "data": {"query": {"some-attribute": 10}}}
 
     assert series_obj._aggregate_query("some-attribute", {"a": 10}) == 10
     mock_query_data.assert_called_with(series_obj.api_client, content)
 
 
+@pytest.mark.parametrize("tags", [{}, {"foo": "bar"}])
 @pytest.mark.parametrize("filters", [[], [{"some": "filter"}]])
 @mock.patch("gantry.query.core.dataframe._raw_query_cached_request")
-def test_aggregate_query_error(mock_query_data, series_obj_factory_with_filters, filters):
-    series_obj = series_obj_factory_with_filters("int", filters=filters)
+def test_aggregate_query_error(
+    mock_query_data, series_obj_factory_with_filters_and_tags, filters, tags
+):
+    series_obj = series_obj_factory_with_filters_and_tags("int", filters=filters, tags=tags)
     mock_query_data.return_value = {"response": "bad", "data": {"query": {"some-attribute": 10}}}
 
     with pytest.raises(
@@ -308,33 +313,42 @@ def test_comparator_invalid_type(method, invalid_dtypes, series_obj_factory):
     ],
 )
 def test_valid_sortable_comparators(method, expected_filter, series_obj_factory):
-    series_obj = series_obj_factory("int", parent_dataframe=mock.Mock(filters=[]))
+    series_obj = series_obj_factory(
+        "int", parent_dataframe=mock.Mock(filters=[], tags={"foo": "bar"})
+    )
     value = 10
     result = getattr(series_obj, method)(value)
     assert [f.filter_ for f in result.filter_objs] == [
         {expected_filter: value, "feature_name": "series_name"}
     ]
     assert [f.series.parent_dataframe for f in result.filter_objs] == [series_obj.parent_dataframe]
+    assert [f.series.parent_dataframe.tags for f in result.filter_objs] == [{"foo": "bar"}]
 
 
 def test_isin(series_obj_factory):
-    series_obj = series_obj_factory("str", parent_dataframe=mock.Mock(filters=[]))
+    series_obj = series_obj_factory(
+        "str", parent_dataframe=mock.Mock(filters=[], tags={"foo": "bar"})
+    )
     value = ["foo"]
     result = series_obj.isin(value)
     assert [f.filter_ for f in result.filter_objs] == [
         {"category_query": value, "feature_name": "series_name"}
     ]
     assert [f.series.parent_dataframe for f in result.filter_objs] == [series_obj.parent_dataframe]
+    assert [f.series.parent_dataframe.tags for f in result.filter_objs] == [{"foo": "bar"}]
 
 
 def test_contains(series_obj_factory):
-    series_obj = series_obj_factory("str", parent_dataframe=mock.Mock(filters=[]))
+    series_obj = series_obj_factory(
+        "str", parent_dataframe=mock.Mock(filters=[], tags={"foo": "bar"})
+    )
     value = "foo"
     result = series_obj.contains(value)
     assert [f.filter_ for f in result.filter_objs] == [
         {"string_query": value, "feature_name": "series_name"}
     ]
     assert [f.series.parent_dataframe for f in result.filter_objs] == [series_obj.parent_dataframe]
+    assert [f.series.parent_dataframe.tags for f in result.filter_objs] == [{"foo": "bar"}]
 
 
 @pytest.mark.parametrize("invalid_key", [object(), 1.2, 123, "some-value"])
@@ -359,14 +373,17 @@ def test_getitem(get_application_node_id_mock, metadata, series_obj_factory, api
         start_time=START_TIME,
         end_time=END_TIME,
         filters=[],
+        tags={"foo": "bar"},
     )
 
     series_obj = series_obj_factory("int", df, name="A")
+    assert series_obj.parent_dataframe.tags == {"foo": "bar"}
 
     filters = dataframe.Filters._from_single_filter({"foo": "bar"}, series_obj)
 
     new_series = series_obj[filters]
     assert new_series.name == "A"
+    assert new_series.parent_dataframe.tags == {"foo": "bar"}
 
 
 @pytest.mark.parametrize(
@@ -380,7 +397,9 @@ def test_getitem(get_application_node_id_mock, metadata, series_obj_factory, api
     ],
 )
 def test_eq(type_, expected, series_obj_factory):
-    series_obj = series_obj_factory(type_, parent_dataframe=mock.Mock(filters=[]))
+    series_obj = series_obj_factory(
+        type_, parent_dataframe=mock.Mock(filters=[], tags={"foo" "bar"})
+    )
     value = 10
     result = series_obj == value
     assert [f.filter_ for f in result.filter_objs] == [
@@ -400,7 +419,9 @@ def test_eq(type_, expected, series_obj_factory):
     ],
 )
 def test_ne(type_, expected, other, value, series_obj_factory):
-    series_obj = series_obj_factory(type_, parent_dataframe=mock.Mock(filters=[]))
+    series_obj = series_obj_factory(
+        type_, parent_dataframe=mock.Mock(filters=[], tags={"foo": "bar"})
+    )
     result = series_obj != other
     assert [f.filter_ for f in result.filter_objs] == [
         {expected: value, "feature_name": "series_name"}
@@ -417,7 +438,9 @@ def test_ne(type_, expected, other, value, series_obj_factory):
     ],
 )
 def test_unary(method, dtype, query_type, value, series_obj_factory):
-    series_obj = series_obj_factory(dtype, parent_dataframe=mock.Mock(filters=[]))
+    series_obj = series_obj_factory(
+        dtype, parent_dataframe=mock.Mock(filters=[], tags={"foo": "bar"})
+    )
     result = getattr(series_obj, method)()
     assert [f.filter_ for f in result.filter_objs] == [
         {query_type: value, "feature_name": "series_name"}
@@ -447,46 +470,58 @@ def test_cannot_compare_type__eq___and__ne__(method, series_obj_factory):
 
 
 def test_filter_builder(series_obj_factory):
-    series_obj = series_obj_factory("int", parent_dataframe=mock.Mock(filters=[{"bar": "baz"}]))
+    series_obj = series_obj_factory(
+        "int", parent_dataframe=mock.Mock(filters=[{"bar": "baz"}], tags={"foo": "bar"})
+    )
     res = series_obj._filter_builder("foo", "bar")
     assert [f.filter_ for f in res.filter_objs] == [{"feature_name": "series_name", "foo": "bar"}]
     assert [f.series.parent_dataframe for f in res.filter_objs] == [series_obj.parent_dataframe]
     assert series_obj.parent_dataframe.filters == [{"bar": "baz"}]
+    assert series_obj.parent_dataframe.tags == {"foo": "bar"}
 
 
 @pytest.mark.parametrize("n", [1, 5, 10, 11])
 @mock.patch("gantry.query.core.dataframe.GantryQueryFrame._populate_raw_request")
 @mock.patch("gantry.query.core.dataframe.GantryQueryFrame._prepare_pandas_dataframe")
 def test_head(mock_df, mock_data, n, series_obj_factory):
-    series_obj = series_obj_factory("int", parent_dataframe=mock.Mock(filters=[]))
+    series_obj = series_obj_factory(
+        "int", parent_dataframe=mock.Mock(filters=[], tags={"foo": "bar"})
+    )
     total_num_events = 10
     all_events = list(range(total_num_events))
     mock_data.return_value = all_events[:n]
     mock_df.return_value = pd.DataFrame({"foo": mock_data.return_value})
     pd.testing.assert_frame_equal(series_obj.head(n), mock_df.return_value)
+    mock_data.assert_called_with(query_filters=[], ascending=True, n=n, tags={"foo": "bar"})
 
 
 @pytest.mark.parametrize("n", [1, 5, 10, 11])
 @mock.patch("gantry.query.core.dataframe.GantryQueryFrame._populate_raw_request")
 @mock.patch("gantry.query.core.dataframe.GantryQueryFrame._prepare_pandas_dataframe")
 def test_tail(mock_df, mock_data, n, series_obj_factory):
-    series_obj = series_obj_factory("int", parent_dataframe=mock.Mock(filters=[]))
+    series_obj = series_obj_factory(
+        "int", parent_dataframe=mock.Mock(filters=[], tags={"foo": "bar"})
+    )
     total_num_events = 10
     all_events = list(range(total_num_events))
     mock_data.return_value = all_events[-n:]
     mock_df.return_value = pd.DataFrame({"foo": mock_data.return_value})
     pd.testing.assert_frame_equal(series_obj.tail(n), mock_df.return_value)
+    mock_data.assert_called_with(query_filters=[], ascending=False, n=n, tags={"foo": "bar"})
 
 
 @mock.patch("gantry.query.core.dataframe.GantryQueryFrame._populate_raw_request")
 @mock.patch("gantry.query.core.dataframe.GantryQueryFrame._prepare_pandas_dataframe")
 def test_fetch(mock_df, mock_data, series_obj_factory):
-    series_obj = series_obj_factory("int", parent_dataframe=mock.Mock(filters=[]))
+    series_obj = series_obj_factory(
+        "int", parent_dataframe=mock.Mock(filters=[], tags={"foo": "bar"})
+    )
     total_num_events = 10
     all_events = list(range(total_num_events))
     mock_data.return_value = all_events
     mock_df.return_value = pd.DataFrame({"foo": mock_data.return_value})
     pd.testing.assert_frame_equal(series_obj.fetch(), mock_df.return_value)
+    mock_data.assert_called_with(query_filters=[], ascending=True, n=None, tags={"foo": "bar"})
 
 
 @mock.patch("gantry.query.core.dataframe.GantrySeries._describe")
@@ -602,6 +637,7 @@ def test_mix_filtering(get_application_node_id_mock, metadata, series_obj_factor
         start_time=START_TIME,
         end_time=END_TIME,
         filters=[],
+        tags={"foo": "bar"},
     )
     s1 = series_obj_factory("int", df, name="A")
     s2 = series_obj_factory("int", df, name="B")
@@ -609,6 +645,7 @@ def test_mix_filtering(get_application_node_id_mock, metadata, series_obj_factor
     series = s1[s2 > 20]
     assert series.name == "A"
     assert series.parent_dataframe.filters == [{"feature_name": "B", "lower_bound": 20}]
+    assert series.parent_dataframe.tags == {"foo": "bar"}
 
 
 @mock.patch(
@@ -629,6 +666,7 @@ def test_compose_filtering(
         start_time=START_TIME,
         end_time=END_TIME,
         filters=[],
+        tags={"foo": "bar"},
     )
 
     s1 = series_obj_factory("int", parent_dataframe=df, name="A")
@@ -640,3 +678,4 @@ def test_compose_filtering(
         {"feature_name": "A", "lower_bound": 20},
         {"feature_name": "A", "upper_bound": 10},
     ]
+    assert s3.parent_dataframe.tags == {"foo": "bar"}
