@@ -1,6 +1,8 @@
 from datetime import datetime
 
 import mock
+import numpy as np
+import pandas as pd
 import pytest
 import responses
 from freezegun import freeze_time
@@ -9,6 +11,7 @@ from responses import matchers
 from gantry.exceptions import GantryException
 from gantry.query.core.constants import GENERIC_MESSAGE
 from gantry.query.core.utils import (
+    _build_empty_df_with_schema,
     check_response,
     get_application_node_id,
     get_application_views,
@@ -345,3 +348,29 @@ def test_get_start_end_time_from_view(view, expected):
 def test_get_start_end_time_from_view_error(invalid_view):
     with pytest.raises(ValueError):
         get_start_end_time_from_view(invalid_view)
+
+
+def test_build_empty_df_with_schema():
+    schema = pd.Series(
+        ["int", "str", "float", "category", "bool", "unk"], index=["A", "B", "C", "D", "E", "F"]
+    )
+    empty_df = _build_empty_df_with_schema(schema)
+
+    assert len(empty_df) == 0
+    assert len(empty_df.columns) == 6
+
+    assert empty_df.columns[0] == "A"
+    assert empty_df.columns[1] == "B"
+    assert empty_df.columns[2] == "C"
+    assert empty_df.columns[3] == "D"
+    assert empty_df.columns[4] == "E"
+    assert empty_df.columns[5] == "F"
+
+    assert list(empty_df.dtypes.iteritems()) == [
+        ("A", np.dtype("int64")),
+        ("B", np.dtype("O")),
+        ("C", np.dtype("float")),
+        ("D", pd.CategoricalDtype(categories=[])),
+        ("E", np.dtype("bool")),
+        ("F", np.dtype("O")),
+    ]
